@@ -3,8 +3,7 @@ from input import SearchContent
 from output import CrawledContent
 
 
-if __name__ == '__main__':
-
+def search():
     search_content = SearchContent.user_input()
     search_list = search_content.convert_to_list()
     c_content = CrawledContent.user_input()
@@ -25,3 +24,7 @@ if __name__ == '__main__':
             c_content.export()
         index_page.driver.quit()
     print("--------查询结束--------")
+
+
+if __name__ == '__main__':
+    search()
