@@ -18,7 +18,8 @@ class SearchPage:
 
     def __init__(self, domain):
         self.domain = re.sub(r"http://|https://|www.", "", domain)
-        self.search_box_file = os.getcwd().replace('\\', '/') + "/param/searchbox_of_searchpage.json"
+        # self.search_box_file = os.getcwd().replace('\\', '/') + "/param/searchbox_of_searchpage.json"
+        self.search_box_file = "param/searchbox_of_searchpage.json"
         with open(self.search_box_file, encoding='utf-8') as json_file:
             self.search_box_dict = json.load(json_file)
         self.search_method = self.search_box_dict.get(self.domain, {}).get('method')
